import './style.css';
import PolylineUtil from 'polyline-encoded'; // This must be imported just like this!

// Initializing the map

const neshanMap = new L.Map('map', {
	key: import.meta.env.VITE_NESHAN_MAP_API_KEY,
	maptype: 'neshan',
	poi: false,
	traffic: false,
	center: [35.699756, 51.338076],
	zoom: 14,
});

// Add a marker

L.marker([35.699756, 51.338076]).addTo(neshanMap);

// Define some custom styles for marker

const redIcon = new L.Icon({
	iconUrl: '/marker.svg',
	// shadowUrl: '/marker.svg',
	iconSize: [40, 40],
	iconAnchor: [12, 41],
	popupAnchor: [1, -34],
	shadowSize: [41, 41],
});

// Create popup for the marker

const popup = L.popup().setContent(
	'<p style="text-align:center;">سلام<br/>با نگه داشتن موس می‌توانید من را جابه‌جا کنید</p>'
);

// Add custom draggable marker

L.marker([35.700357, 51.359829], {
	icon: redIcon,
	draggable: true,
	title: 'توضیحات مد نظر شما',
	opacity: 1,
})
	.bindPopup(popup)
	.addTo(neshanMap)
	.openPopup();

const exampleResponse = {
	routes: [
		{
			overview_polyline: {
				points: 'cy{xEa{sxHCyEr@}FIi@MWi@Um@L[l@A^{Jr@',
			},
			legs: [
				{
					summary: 'میدان انقلاب اسلامی - کارگر شمالی',
					distance: {
						value: 555.0,
						text: '۵۷۵ متر',
					},
					duration: {
						value: 99.0,
						text: '۲ دقیقه',
					},
					steps: [
						{
							name: 'آزادی',
							instruction: 'در جهت شرق در آزادی قرار بگیرید',
							bearing_after: 88,
							type: 'depart',
							distance: {
								value: 197.0,
								text: '۲۰۰ متر',
							},
							duration: {
								value: 35.0,
								text: '۱ دقیقه',
							},
							polyline: 'cy{xEa{sxHAkBAmBDa@BKHs@BWD]J{@',
							start_location: [51.388811, 35.70082],
						},
						{
							name: 'کارگر شمالی',
							instruction:
								'در میدان انقلاب اسلامی، از خروجی سوم، خارج شوید',
							rotaryName: 'میدان انقلاب اسلامی',
							bearing_after: 111,
							type: 'rotary',
							modifier: 'straight',
							exit: 3,
							distance: {
								value: 146.0,
								text: '۱۵۰ متر',
							},
							duration: {
								value: 38.0,
								text: '۱ دقیقه',
							},
							polyline: '}w{xEohtxHDSBUCUESEKGKSOUEW@UJORKXAN?N',
							start_location: [51.390956, 35.700632],
						},
						{
							name: '',
							instruction: 'به مسیر خود ادامه دهید',
							bearing_after: 354,
							type: 'exit rotary',
							modifier: 'right',
							exit: 3,
							distance: {
								value: 212.0,
								text: '۲۲۵ متر',
							},
							duration: {
								value: 39.0,
								text: '۱ دقیقه',
							},
							polyline: 'a|{xEuitxH_ADaBLO@{BRmAH',
							start_location: [51.391154, 35.701293],
						},
						{
							name: 'کارگر شمالی',
							instruction: 'در مقصد قرار دارید',
							bearing_after: 0,
							type: 'arrive',
							distance: {
								value: 0.0,
								text: '',
							},
							duration: {
								value: 0.0,
								text: '',
							},
							polyline: '}g|xEahtxH',
							start_location: [51.390885, 35.703188],
						},
					],
				},
			],
		},
	],
};

// Iterate through response steps

for (let k = 0; k < Object.keys(exampleResponse.routes).length; k++) {
	for (
		let j = 0;
		j < Object.keys(exampleResponse.routes[k].legs).length;
		j++
	) {
		for (
			let i = 0;
			i < Object.keys(exampleResponse.routes[k].legs[j].steps).length;
			i++
		) {
			var step = exampleResponse.routes[k].legs[j].steps[i];

			// Decode encoded polyline and draw on map

			L.Polyline.fromEncoded(step.polyline, {
				color: '#250ECD',
				weight: 12,
			}).addTo(neshanMap);

			// Add point in start of step

			L.circleMarker([step.start_location[1], step.start_location[0]], {
				weight: 1,
				color: '#FFFFFF',
				radius: 5,
				fill: true,
				fillColor: '#9fbef9',
				fillOpacity: 1.0,
			}).addTo(neshanMap);
		}
	}
}
